==> OOo_2.2.1_Win32Intel_solver_curvirgo.zip: solver/680/wntmsci10.pro/inc/offuh/com/sun/star/inspection/LineDescriptor.hpp <==
#ifndef _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HPP_
#define _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HDL_
#include "com/sun/star/inspection/LineDescriptor.hdl"
#endif

#ifndef _COM_SUN_STAR_INSPECTION_XPROPERTYCONTROL_HPP_
#include "com/sun/star/inspection/XPropertyControl.hpp"
#endif
#ifndef _COM_SUN_STAR_GRAPHIC_XGRAPHIC_HPP_
#include "com/sun/star/graphic/XGraphic.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace inspection {

inline LineDescriptor::LineDescriptor() SAL_THROW( () )
    : DisplayName()
    , Control()
    , HelpURL()
    , HasPrimaryButton(false)
    , HasSecondaryButton(false)
    , PrimaryButtonId(0)
    , SecondaryButtonId(0)
    , PrimaryButtonImage()
    , SecondaryButtonImage()
    , IndentLevel(0)
    , Category()
{
}

inline LineDescriptor::LineDescriptor(const ::rtl::OUString& DisplayName_, const ::com::sun::star::uno::Reference< ::com::sun::star::inspection::XPropertyControl >& Control_, const ::rtl::OUString& HelpURL_, const ::sal_Bool& HasPrimaryButton_, const ::sal_Bool& HasSecondaryButton_, const ::sal_Int32& PrimaryButtonId_, const ::sal_Int32& SecondaryButtonId_, const ::com::sun::star::uno::Reference< ::com::sun::star::graphic::XGraphic >& PrimaryButtonImage_, const ::com::sun::star::uno::Reference< ::com::sun::star::graphic::XGraphic >& SecondaryButtonImage_, const ::sal_Int16& IndentLevel_, const ::rtl::OUString& Category_) SAL_THROW( () )
    : DisplayName(DisplayName_)
    , Control(Control_)
    , HelpURL(HelpURL_)
    , HasPrimaryButton(HasPrimaryButton_)
    , HasSecondaryButton(HasSecondaryButton_)
    , PrimaryButtonId(PrimaryButtonId_)
    , SecondaryButtonId(SecondaryButtonId_)
    , PrimaryButtonImage(PrimaryButtonImage_)
    , SecondaryButtonImage(SecondaryButtonImage_)
    , IndentLevel(IndentLevel_)
    , Category(Category_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace inspection {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::inspection::LineDescriptor const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.inspection.LineDescriptor");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::inspection::LineDescriptor const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::inspection::LineDescriptor >::get();
}

#endif // _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HPP_

==> OOo_2.3.0_Win32Intel_solver_curvirgo.zip: solver/680/wntmsci10.pro/inc/offuh/com/sun/star/inspection/LineDescriptor.hpp <==
#ifndef _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HPP_
#define _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HDL_
#include "com/sun/star/inspection/LineDescriptor.hdl"
#endif

#ifndef _COM_SUN_STAR_INSPECTION_XPROPERTYCONTROL_HPP_
#include "com/sun/star/inspection/XPropertyControl.hpp"
#endif
#ifndef _COM_SUN_STAR_GRAPHIC_XGRAPHIC_HPP_
#include "com/sun/star/graphic/XGraphic.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _RTL_USTRING_HXX_
#include "rtl/ustring.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace inspection {

inline LineDescriptor::LineDescriptor() SAL_THROW( () )
    : DisplayName()
    , Control()
    , HelpURL()
    , HasPrimaryButton(false)
    , PrimaryButtonId(0)
    , PrimaryButtonImageURL()
    , PrimaryButtonImage()
    , HasSecondaryButton(false)
    , SecondaryButtonId(0)
    , SecondaryButtonImageURL()
    , SecondaryButtonImage()
    , IndentLevel(0)
    , Category()
{
}

inline LineDescriptor::LineDescriptor(const ::rtl::OUString& DisplayName_, const ::com::sun::star::uno::Reference< ::com::sun::star::inspection::XPropertyControl >& Control_, const ::rtl::OUString& HelpURL_, const ::sal_Bool& HasPrimaryButton_, const ::sal_Int32& PrimaryButtonId_, const ::rtl::OUString& PrimaryButtonImageURL_, const ::com::sun::star::uno::Reference< ::com::sun::star::graphic::XGraphic >& PrimaryButtonImage_, const ::sal_Bool& HasSecondaryButton_, const ::sal_Int32& SecondaryButtonId_, const ::rtl::OUString& SecondaryButtonImageURL_, const ::com::sun::star::uno::Reference< ::com::sun::star::graphic::XGraphic >& SecondaryButtonImage_, const ::sal_Int16& IndentLevel_, const ::rtl::OUString& Category_) SAL_THROW( () )
    : DisplayName(DisplayName_)
    , Control(Control_)
    , HelpURL(HelpURL_)
    , HasPrimaryButton(HasPrimaryButton_)
    , PrimaryButtonId(PrimaryButtonId_)
    , PrimaryButtonImageURL(PrimaryButtonImageURL_)
    , PrimaryButtonImage(PrimaryButtonImage_)
    , HasSecondaryButton(HasSecondaryButton_)
    , SecondaryButtonId(SecondaryButtonId_)
    , SecondaryButtonImageURL(SecondaryButtonImageURL_)
    , SecondaryButtonImage(SecondaryButtonImage_)
    , IndentLevel(IndentLevel_)
    , Category(Category_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace inspection {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::inspection::LineDescriptor const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.inspection.LineDescriptor");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::inspection::LineDescriptor const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::inspection::LineDescriptor >::get();
}

#endif // _COM_SUN_STAR_INSPECTION_LINEDESCRIPTOR_HPP_
